@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
+  Copyright (C) 2003  Sridhar Ratnakumar <srid@srid.ca>
 	
   This file is part of GNUSim8085.
 
@@ -20,11 +20,9 @@
 */
 //Instructions TODO: RIM, SIM, ~RST
 
-#ifdef HAVE_CONFIG_
-#  include <config.h>
-#endif
 
 #include "8085-instructions.h"
+#include "config.h"
 
 #define ERR_IV_OP _("Invalid Opcode")
 
@@ -741,7 +739,7 @@ _eef_inst_func_17 (eef_addr_t opnd_addr)
   return _eef_inst_func_lxi (opnd_addr, 'D');
 }
 
-/* 12 STAX H */
+/* 12 STAX D */
 static gint
 _eef_inst_func_18 (eef_addr_t opnd_addr)
 {
