@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
+  Copyright (C) 2003  Sridhar Ratnakumar <srid@srid.ca>
 	
   This file is part of GNUSim8085.
 
@@ -18,11 +18,9 @@
   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
   02110-1301, USA.
 */
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
 
 #include "callbacks.h"
+#include "config.h"
 #include "interface.h"
 #include "gui-app.h"
 #include "gui-editor.h"
@@ -135,13 +133,13 @@ void on_font_select_activate (GtkAction * menuitem, gpointer user_data)
   const gchar *font_name = gui_editor_get_font (app->editor);
   gint action = 0;
   g_assert (app->editor);
-  font_selection_dialog = gtk_font_selection_dialog_new (_("Select font"));
-  gtk_font_selection_dialog_set_font_name (GTK_FONT_SELECTION_DIALOG (font_selection_dialog), font_name);
+  font_selection_dialog = gtk_font_chooser_dialog_new (_("Select font"), NULL);
+  gtk_font_chooser_set_font (GTK_FONT_CHOOSER (font_selection_dialog), font_name);
   action = gtk_dialog_run (GTK_DIALOG (font_selection_dialog));
   switch (action) 
   {
     case GTK_RESPONSE_OK:
-      font_name = gtk_font_selection_dialog_get_font_name (GTK_FONT_SELECTION_DIALOG (font_selection_dialog));
+      font_name = gtk_font_chooser_get_font (GTK_FONT_CHOOSER (font_selection_dialog));
       if (font_name)
       {
         gui_editor_set_font (app->editor, font_name);
@@ -346,15 +344,17 @@ on_stop_execution1_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_help_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-  //TODO: gnome-help
-  gtk_widget_show (create_window_start ());
-}
-
-
-void
-on_8085_manual1_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  gtk_widget_show (create_window_start ());
+  // Show the HTML help.
+#ifdef G_OS_WIN32
+  gchar * html_file_name = g_build_filename (g_win32_get_package_installation_directory_of_module (NULL), "help", "userguide.htm", NULL);
+#else
+  gchar * html_file_name = g_build_filename (PACKAGE_HELP_DIR, "userguide.htm", NULL);
+#endif
+  gchar * html_help_uri = g_filename_to_uri(html_file_name, NULL, NULL);
+  g_debug ("HTML Help URI: %s\n", html_help_uri);
+  gtk_show_uri (gdk_screen_get_default(), html_help_uri, GDK_CURRENT_TIME, NULL);
+  g_free (html_file_name);
+  g_free (html_help_uri);
 }
 
 
@@ -377,7 +377,7 @@ void
 show_hide_side_pane (GtkToggleAction * menuitem, gpointer user_data)
 {
   GtkWidget *side_pane;
-  side_pane = lookup_widget (app->window_main, "main_vpaned_data");
+  side_pane = lookup_widget (app->window_main, "vbox_data");
   if (gtk_toggle_action_get_active (menuitem))
 	  gtk_widget_hide (side_pane);
   else
@@ -500,7 +500,7 @@ on_show_listing1_activate (GtkMenuItem * menuitem, gpointer user_data)
   gui_editor_show (edit);
   gui_editor_set_text (edit, list->str);
   gui_editor_set_readonly (edit, TRUE);
-  gtk_box_pack_end_defaults (GTK_BOX (cont), edit->scroll);
+  gtk_box_pack_end (GTK_BOX (cont), edit->scroll, TRUE, TRUE, 0);
   gtk_window_maximize (GTK_WINDOW (wind));
   gtk_widget_show_all (wind);
   /* TODO clean up of listing window editor on delete event */
@@ -710,7 +710,7 @@ show_tutorial ()
   gui_editor_set_text (edit, tutorial_text->str);
   gui_editor_set_readonly (edit, TRUE);
   gui_editor_set_show_line_numbers (edit, FALSE);
-  gtk_box_pack_end_defaults (GTK_BOX (cont), edit->scroll);
+  gtk_box_pack_end (GTK_BOX (cont), edit->scroll, TRUE, TRUE, 0);
   gtk_window_maximize (GTK_WINDOW (tutorial));
   gtk_widget_show_all (tutorial);
 
