@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
+  Copyright (C) 2003  Sridhar Ratnakumar <srid@srid.ca>
 	
   This file is part of GNUSim8085.
 
@@ -19,10 +19,7 @@
   02110-1301, USA.
 */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
+#include "config.h"
 #include "file-op.h"
 #include "gui-editor.h"
 #include "gui-app.h"
@@ -200,7 +197,7 @@ hlt";
 
   /* Set template text */
   gui_editor_set_text (app->editor, template);
-  gui_editor_goto_line (app->editor, 11);
+  gui_editor_goto_line (app->editor, 13);
   gtk_text_buffer_set_modified ((GtkTextBuffer *)app->editor->buffer, FALSE);
 }
 
@@ -216,7 +213,7 @@ file_op_editor_save (void)
   gboolean is_saved = FALSE;
 
   file_selector = create_file_dialog
-	("Save File", GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_SAVE);
+	(_("Save file"), GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_SAVE);
 
   while (!is_saved)
 	{
@@ -246,7 +243,7 @@ file_op_editor_save_as (void)
   gboolean is_saved = FALSE;
 
   file_selector = create_file_dialog
-	("Save File As", GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_SAVE);
+	(_("Save file as"), GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_SAVE);
 
   while (!is_saved)
 	{
