@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
+  Copyright (C) 2003  Sridhar Ratnakumar <srid@srid.ca>
 	
   This file is part of GNUSim8085.
 
@@ -23,6 +23,7 @@
 #include "asm-id.h"
 #include "gui-app.h"
 #include "gui-input-symbol.h"
+#include "interface.h"
 #include "bridge.h"
 
 static GtkWidget *table;
@@ -193,7 +194,9 @@ create_me (void)
   opcode = asm_id_get_opcode ();
 
   /* Construct a table of cells */
-  table = gtk_table_new (TABLE_ROWS, TABLE_COLS, TRUE);
+  table = gtk_grid_new ();
+  gtk_grid_set_column_homogeneous (GTK_GRID (table), TRUE);
+  gtk_grid_set_row_homogeneous (GTK_GRID (table), TRUE);
 	
   g_signal_connect (table, "focus", (GCallback) cb_focus, NULL);
 	
@@ -215,8 +218,7 @@ create_me (void)
 		  gtk_widget_set_tooltip_text (button, op->op_desc);
 		  g_signal_connect (button, "clicked",
 							(GCallback) cb_clicked, op);
-		  gtk_table_attach_defaults (GTK_TABLE (table), button,
-									 j, j + 1, i, i + 1);
+		  TABLE_ATTACH_DEFAULTS (table, button, j, j + 1, i, i + 1);
 		}
 	}
  breakout:
