@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
+  Copyright (C) 2003  Sridhar Ratnakumar <srid@srid.ca>
 	
   This file is part of GNUSim8085.
 
@@ -19,10 +19,7 @@
   02110-1301, USA.
 */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
+#include "config.h"
 #include "gui-list-data.h"
 #include "gui-app.h"
 #include "8085.h"
