@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
+  Copyright (C) 2003  Sridhar Ratnakumar <srid@srid.ca>
 	
   This file is part of GNUSim8085.
 
@@ -19,10 +19,7 @@
   02110-1301, USA.
 */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
+#include "config.h"
 #include "gui-list-message.h"
 #include "gui-app.h"
 
@@ -72,9 +69,9 @@ cb_clicked (GtkTreeView * listview, gpointer user_data)
 	return;
 
   gtk_widget_grab_focus (app->editor->widget);
-  gui_editor_goto_line (app->editor, ln-1);
+  gui_editor_goto_line (app->editor, ln);
   gui_editor_clear_all_highlights (app->editor);
-  gui_editor_set_highlight (app->editor, ln-1, TRUE);
+  gui_editor_set_highlight (app->editor, ln, TRUE);
 
 }
 
@@ -106,12 +103,12 @@ gui_list_message_attach_me (void)
 {
   GtkWidget *cont;
 
-  cont = lookup_widget (app->window_main, "main_vpaned_data");
+  cont = lookup_widget (app->window_main, "vbox_data");
   g_assert (cont);
 
   create_me ();
 
-  gtk_paned_add2 (GTK_PANED (cont), GTK_WIDGET (view));
+  gtk_box_pack_end (GTK_BOX (cont), GTK_WIDGET (view), TRUE, TRUE, 0);
 
 }
 
