@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003  Sridhar Ratnakumar <sridhar.ratna@gmail.com>
+  Copyright (C) 2003  Sridhar Ratnakumar <srid@srid.ca>
         
   This file is part of GNUSim8085.
 
@@ -29,6 +29,7 @@
 
 #define _(String) gettext (String)
 #define N_(String) (String)
+#define GTK_(String) dgettext ("gtk30", String)
 
 /*
  * Public Functions.
@@ -65,3 +66,10 @@ gchar**  read_authors ();
 
 /* This is used to read tutorial from asm-guide.txt file. */
 GString*  read_tutorial ();
+
+/* A wrapper function to create button with stock items. */
+GtkWidget*  button_from_stock (const gchar *label, const gchar *icon_name);
+
+/* A wrapper function to create button with stock image and custom label. */
+GtkWidget*  button_from_stock_img_custom_label (const gchar *label,
+		const gchar *icon_name);
